==> tdepim-trinity-14.0.6.tar.xz: tdepim-trinity-14.0.6/config.h.cmake <==

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@

// libkcal
#cmakedefine USE_LIBICAL_0_46 1

// kalarm
#cmakedefine WITHOUT_ARTS 1

// ktnef
#cmakedefine HAVE_INTTYPES_H 1
#cmakedefine HAVE_STDINT_H 1
#cmakedefine SIZEOF_UNSIGNED_LONG_LONG @SIZEOF_UNSIGNED_LONG_LONG@
#cmakedefine SIZEOF_UNSIGNED_LONG @SIZEOF_UNSIGNED_LONG@
#cmakedefine SIZEOF_UINT64_T @SIZEOF_UINT64_T@

// libtdepim, kmail
#cmakedefine TDEPIM_NEW_DISTRLISTS 1

// libkdemanager, certmanager
#cmakedefine HAVE_GPGME_0_4_BRANCH 1

// libtdenetwork
#cmakedefine HAVE_GPGME_KEYLIST_MODE_VALIDATE 1
#cmakedefine HAVE_GPGME_CANCEL 1
#cmakedefine HAVE_GPGME_KEY_T_KEYLIST_MODE 1
#cmakedefine HAVE_GPGME_WRONG_KEY_USAGE 1
#cmakedefine HAVE_GPGME_INCLUDE_CERTS_DEFAULT 1
#cmakedefine HAVE_GPGME_OP_GETAUDITLOG 1

// certmanager
#cmakedefine MAX_CMD_LENGTH @MAX_CMD_LENGTH@
#cmakedefine HAVE_C99_INITIALIZERS 1

// tdeioslave
#cmakedefine HAVE_LIBSASL2 1

// kmail
#cmakedefine HAVE_BYTESWAP_H 1
#cmakedefine HAVE_STLNAMESPACE 1
#cmakedefine STD_NAMESPACE_PREFIX @STD_NAMESPACE_PREFIX@

// kaddressbook
#cmakedefine TDEPIM_NEW_DISTRLISTS 1

// karm
#cmakedefine HAVE_LIBXSS 1

// mimelib
#ifdef __cplusplus
extern "C" {
#endif
unsigned long strlcpy(char*, const char*, unsigned long);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C" {
#endif
unsigned long strlcat(char*, const char*, unsigned long);
#ifdef __cplusplus
}
#endif

==> tdepim-trinity-14.0.7.tar.xz: tdepim-trinity-14.0.7/config.h.cmake <==

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@

// libkcal
#cmakedefine USE_LIBICAL_0_46 1

// kalarm
#cmakedefine WITHOUT_ARTS 1

// ktnef
#cmakedefine HAVE_INTTYPES_H 1
#cmakedefine HAVE_STDINT_H 1
#cmakedefine SIZEOF_UNSIGNED_LONG_LONG @SIZEOF_UNSIGNED_LONG_LONG@
#cmakedefine SIZEOF_UNSIGNED_LONG @SIZEOF_UNSIGNED_LONG@
#cmakedefine SIZEOF_UINT64_T @SIZEOF_UINT64_T@

// libtdepim, kmail
#cmakedefine TDEPIM_NEW_DISTRLISTS 1

// libkdemanager, certmanager
#cmakedefine HAVE_GPGME_0_4_BRANCH 1

// libtdenetwork
#cmakedefine HAVE_GPGME_KEYLIST_MODE_VALIDATE 1
#cmakedefine HAVE_GPGME_CANCEL 1
#cmakedefine HAVE_GPGME_KEY_T_KEYLIST_MODE 1
#cmakedefine HAVE_GPGME_WRONG_KEY_USAGE 1
#cmakedefine HAVE_GPGME_INCLUDE_CERTS_DEFAULT 1
#cmakedefine HAVE_GPGME_OP_GETAUDITLOG 1

// certmanager
#cmakedefine MAX_CMD_LENGTH @MAX_CMD_LENGTH@
#cmakedefine HAVE_C99_INITIALIZERS 1

// tdeioslave
#cmakedefine HAVE_LIBSASL2 1

// kmail
#cmakedefine HAVE_BYTESWAP_H 1
#cmakedefine HAVE_STLNAMESPACE 1
#cmakedefine STD_NAMESPACE_PREFIX @STD_NAMESPACE_PREFIX@

// kaddressbook
#cmakedefine TDEPIM_NEW_DISTRLISTS 1

// karm
#cmakedefine HAVE_LIBXSS 1

// mimelib
#cmakedefine HAVE_STRLCPY_PROTO

#cmakedefine HAVE_STRLCAT_PROTO

#if !defined(HAVE_STRLCPY_PROTO)
#ifdef __cplusplus
extern "C" {
#endif
unsigned long strlcpy(char*, const char*, unsigned long);
#ifdef __cplusplus
}
#endif
#endif

#if !defined(HAVE_STRLCAT_PROTO)
#ifdef __cplusplus
extern "C" {
#endif
unsigned long strlcat(char*, const char*, unsigned long);
#ifdef __cplusplus
}
#endif
#endif
